==> scala-k8s-objects_sjs1_2.12-0.3.0-sources.jar: io/k8s/api/core/v1/GitRepoVolumeSource.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** Represents a volume that is populated with the contents of a git repository. Git repo volumes do not support ownership management. Git repo volumes support SELinux relabeling.

DEPRECATED: GitRepo is deprecated. To provision a container with a git repo, mount an EmptyDir into an InitContainer that clones the repo using git, then mount the EmptyDir into the Pod's container. */
final case class GitRepoVolumeSource(
  repository : String,
  directory : Option[String] = None,
  revision : Option[String] = None
) {

  /** Returns a new data with repository set to new value */
  def withRepository(value: String) : GitRepoVolumeSource = copy(repository = value)
  /** transforms repository to result of function */
  def mapRepository(f: String => String) : GitRepoVolumeSource = copy(repository = f(repository))

  /** Returns a new data with directory set to new value */
  def withDirectory(value: String) : GitRepoVolumeSource = copy(directory = Some(value))
  /** if directory has a value, transforms to the result of function*/
  def mapDirectory(f: String => String) : GitRepoVolumeSource = copy(directory = directory.map(f))

  /** Returns a new data with revision set to new value */
  def withRevision(value: String) : GitRepoVolumeSource = copy(revision = Some(value))
  /** if revision has a value, transforms to the result of function*/
  def mapRevision(f: String => String) : GitRepoVolumeSource = copy(revision = revision.map(f))
}

object GitRepoVolumeSource {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.GitRepoVolumeSource, T] = new Encoder[io.k8s.api.core.v1.GitRepoVolumeSource, T] {
        def apply(o: io.k8s.api.core.v1.GitRepoVolumeSource) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("repository", o.repository)
            .write("directory", o.directory)
            .write("revision", o.revision)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, GitRepoVolumeSource] = new Decoder[T, GitRepoVolumeSource] {
      def apply(t: T): Either[String, GitRepoVolumeSource] = for {
          obj <- ObjectReader(t)
          repository <- obj.read[String]("repository")
          directory <- obj.readOpt[String]("directory")
          revision <- obj.readOpt[String]("revision")
      } yield GitRepoVolumeSource (
          repository = repository,
          directory = directory,
          revision = revision
        )
    }
}

==> scala-k8s-objects_sjs1_2.12-0.18.0-sources.jar: io/k8s/api/core/v1/GitRepoVolumeSource.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** Represents a volume that is populated with the contents of a git repository. Git repo volumes do not support ownership management. Git repo volumes support SELinux relabeling.

DEPRECATED: GitRepo is deprecated. To provision a container with a git repo, mount an EmptyDir into an InitContainer that clones the repo using git, then mount the EmptyDir into the Pod's container. */
final case class GitRepoVolumeSource(
  repository : String,
  directory : Option[String] = None,
  revision : Option[String] = None
) {

  /** Returns a new data with repository set to new value */
  def withRepository(value: String) : GitRepoVolumeSource = copy(repository = value)
  /** transforms repository to result of function */
  def mapRepository(f: String => String) : GitRepoVolumeSource = copy(repository = f(repository))

  /** Returns a new data with directory set to new value */
  def withDirectory(value: String) : GitRepoVolumeSource = copy(directory = Some(value))
  /** if directory has a value, transforms to the result of function*/
  def mapDirectory(f: String => String) : GitRepoVolumeSource = copy(directory = directory.map(f))

  /** Returns a new data with revision set to new value */
  def withRevision(value: String) : GitRepoVolumeSource = copy(revision = Some(value))
  /** if revision has a value, transforms to the result of function*/
  def mapRevision(f: String => String) : GitRepoVolumeSource = copy(revision = revision.map(f))
}

object GitRepoVolumeSource {

    implicit val encoder : Encoder[io.k8s.api.core.v1.GitRepoVolumeSource] = new Encoder[io.k8s.api.core.v1.GitRepoVolumeSource] {
        def apply[T : Builder](o: io.k8s.api.core.v1.GitRepoVolumeSource) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("repository", o.repository)
            .write("directory", o.directory)
            .write("revision", o.revision)
            .build
        }
    }

    implicit val decoder: Decoder[GitRepoVolumeSource] = new Decoder[GitRepoVolumeSource] {
      def apply[T : Reader](t: T): Either[String, GitRepoVolumeSource] = for {
          obj <- ObjectReader(t)
          repository <- obj.read[String]("repository")
          directory <- obj.readOpt[String]("directory")
          revision <- obj.readOpt[String]("revision")
      } yield GitRepoVolumeSource (
          repository = repository,
          directory = directory,
          revision = revision
        )
    }
}
